[Ocfs2-commits] jlbec commits r2100 - trunk/fs/configfs
svn-commits at oss.oracle.com
svn-commits at oss.oracle.com
Thu Mar 31 19:29:41 CST 2005
Author: jlbec
Signed-off-by: manish
Date: 2005-03-31 19:29:40 -0600 (Thu, 31 Mar 2005)
New Revision: 2100
Modified:
trunk/fs/configfs/configfs.h
trunk/fs/configfs/configfs_internal.h
trunk/fs/configfs/dir.c
trunk/fs/configfs/file.c
trunk/fs/configfs/inode.c
trunk/fs/configfs/item.c
trunk/fs/configfs/mount.c
trunk/fs/configfs/symlink.c
Log:
o Whoops, missed one rename
Signed-off-by: manish
Modified: trunk/fs/configfs/configfs.h
===================================================================
--- trunk/fs/configfs/configfs.h 2005-04-01 00:32:10 UTC (rev 2099)
+++ trunk/fs/configfs/configfs.h 2005-04-01 01:29:40 UTC (rev 2100)
@@ -44,7 +44,7 @@
#include <asm/atomic.h>
#include <asm/semaphore.h>
-#define UOBJ_NAME_LEN 20
+#define CONFIGFS_ITEM_NAME_LEN 20
struct module;
@@ -55,7 +55,7 @@
struct config_item {
char *ci_name;
- char ci_namebuf[UOBJ_NAME_LEN];
+ char ci_namebuf[CONFIGFS_ITEM_NAME_LEN];
struct kref ci_kref;
struct list_head ci_entry;
struct config_item *ci_parent;
Modified: trunk/fs/configfs/configfs_internal.h
===================================================================
--- trunk/fs/configfs/configfs_internal.h 2005-04-01 00:32:10 UTC (rev 2099)
+++ trunk/fs/configfs/configfs_internal.h 2005-04-01 01:29:40 UTC (rev 2100)
@@ -44,12 +44,12 @@
#define CONFIGFS_ROOT 0x0001
#define CONFIGFS_DIR 0x0002
-#define CONFIGFS_UOBJ_ATTR 0x0004
-#define CONFIGFS_UOBJ_LINK 0x0020
+#define CONFIGFS_ITEM_ATTR 0x0004
+#define CONFIGFS_ITEM_LINK 0x0020
#define CONFIGFS_USET_DIR 0x0040
#define CONFIGFS_USET_DEFAULT 0x0080
#define CONFIGFS_USET_DROPPING 0x0100
-#define CONFIGFS_NOT_PINNED (CONFIGFS_UOBJ_ATTR)
+#define CONFIGFS_NOT_PINNED (CONFIGFS_ITEM_ATTR)
extern struct vfsmount * configfs_mount;
@@ -112,7 +112,7 @@
spin_lock(&dcache_lock);
if (!d_unhashed(dentry)) {
struct configfs_dirent * sd = dentry->d_fsdata;
- if (sd->s_type & CONFIGFS_UOBJ_LINK) {
+ if (sd->s_type & CONFIGFS_ITEM_LINK) {
struct configfs_symlink * sl = sd->s_element;
item = config_item_get(sl->sl_target);
} else
Modified: trunk/fs/configfs/dir.c
===================================================================
--- trunk/fs/configfs/dir.c 2005-04-01 00:32:10 UTC (rev 2099)
+++ trunk/fs/configfs/dir.c 2005-04-01 01:29:40 UTC (rev 2100)
@@ -187,7 +187,7 @@
err = configfs_create(dentry, mode, init_symlink);
if (!err) {
err = configfs_make_dirent(parent->d_fsdata, dentry, sl,
- mode, CONFIGFS_UOBJ_LINK);
+ mode, CONFIGFS_ITEM_LINK);
if (!err)
dentry->d_op = &configfs_dentry_ops;
}
Modified: trunk/fs/configfs/file.c
===================================================================
--- trunk/fs/configfs/file.c 2005-04-01 00:32:10 UTC (rev 2099)
+++ trunk/fs/configfs/file.c 2005-04-01 01:29:40 UTC (rev 2100)
@@ -355,6 +355,6 @@
BUG_ON(!item || !item->ci_dentry || !attr);
return configfs_add_file(item->ci_dentry, attr,
- CONFIGFS_UOBJ_ATTR);
+ CONFIGFS_ITEM_ATTR);
}
Modified: trunk/fs/configfs/inode.c
===================================================================
--- trunk/fs/configfs/inode.c 2005-04-01 00:32:10 UTC (rev 2099)
+++ trunk/fs/configfs/inode.c 2005-04-01 01:29:40 UTC (rev 2100)
@@ -121,10 +121,10 @@
BUG();
/* These always have a dentry, so use that */
- if (sd->s_type & (CONFIGFS_DIR | CONFIGFS_UOBJ_LINK))
+ if (sd->s_type & (CONFIGFS_DIR | CONFIGFS_ITEM_LINK))
return sd->s_dentry->d_name.name;
- if (sd->s_type & CONFIGFS_UOBJ_ATTR) {
+ if (sd->s_type & CONFIGFS_ITEM_ATTR) {
attr = sd->s_element;
return attr->name;
}
Modified: trunk/fs/configfs/item.c
===================================================================
--- trunk/fs/configfs/mount.c 2005-04-01 00:32:10 UTC (rev 2099)
+++ trunk/fs/configfs/mount.c 2005-04-01 01:29:40 UTC (rev 2100)
@@ -24,8 +24,6 @@
* configfs Copyright (C) 2005 Oracle. All rights reserved.
*/
-#define DEBUG 1
-
#include <linux/fs.h>
#include <linux/module.h>
#include <linux/mount.h>
Modified: trunk/fs/configfs/symlink.c
===================================================================
--- trunk/fs/configfs/symlink.c 2005-04-01 00:32:10 UTC (rev 2099)
+++ trunk/fs/configfs/symlink.c 2005-04-01 01:29:40 UTC (rev 2100)
@@ -160,7 +160,7 @@
int ret;
ret = -EPERM; /* What lack-of-symlink returns */
- if (!(sd->s_type & CONFIGFS_UOBJ_LINK))
+ if (!(sd->s_type & CONFIGFS_ITEM_LINK))
goto out;
if (dentry->d_parent == configfs_sb->s_root)
More information about the Ocfs2-commits
mailing list
--- trunk/fs/configfs/item.c 2005-04-01 00:32:10 UTC (rev 2099)
+++ trunk/fs/configfs/item.c 2005-04-01 01:29:40 UTC (rev 2100)
@@ -58,15 +58,15 @@
* @item: item.
* @name: name.
*
* If strlen(name) >= UOBJ_NAME_LEN, then use a dynamically allocated
* string that @item->ci_name points to. Otherwise, use the static
* @item->ci_namebuf array.
*/
int config_item_set_name(struct config_item * item, const char * fmt, ...)
{
int error = 0;
- int limit = UOBJ_NAME_LEN;
+ int limit = CONFIGFS_ITEM_NAME_LEN;
int need;
va_list args;
char * name;
@@ -58,15 +58,15 @@
* @name: name.
*
- * If strlen(name) >= UOBJ_NAME_LEN, then use a dynamically allocated
- * string that @item->ci_name points to. Otherwise, use the static
- * @item->ci_namebuf array.
+ * If strlen(name) >= CONFIGFS_ITEM_NAME_LEN, then use a
+ * dynamically allocated string that @item->ci_name points to.
+ * Otherwise, use the static @item->ci_namebuf array.
*/
int config_item_set_name(struct config_item * item, const char * fmt, ...)
Modified: trunk/fs/configfs/mount.c
===================================================================